# {{ project_name }}

Describe your project here, let people know how your project will help them!

## Installation

Let people know how they can install your project.

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install foobar.

```bash
pip install foobar
```

Use the package manager [npm](https://www.npmjs.com/) to install foobar.

```bash
npm install foobar
```

## Usage

```python
import foobar

# returns 'words'
foobar.pluralize('word')

# returns 'geese'
foobar.pluralize('goose')

# returns 'phenomenon'
foobar.singularize('phenomena')
```

## Contributing

Pull requests are welcome. For major changes, please open an issue first
to discuss what you would like to change.

Please make sure to update tests as appropriate.

See the [contributing guidelines]({{ github_remote_url }}/blob/master/CONTRIBUTING.md)

## License

For help with licenses, see [https://choosealicense.com/](https://choosealicense.com/)

This readme was generated with help from [https://www.makeareadme.com](https://www.makeareadme.com). You can find additional guidance on their site!
